High-level API commands
***********************

.. currentmodule:: datalad.api
.. autosummary::
   :toctree: generated

   create_sibling_webdav
   credentials
   download
   ls_file_collection
   next_status
   tree
